==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property incidentContactEmail
 * @property incidentRoutingService
 * @property incidentRoutingTeam
 * @property manifestOwners
 * @property resourceAccessPolicy
 * @property resourceAccessRoles
 * @property schemaOwners
 * @property serviceTreeInfos
 */
public data class ResourceTypeRegistrationPropertiesManagementArgs(
    public val incidentContactEmail: Output<String>? = null,
    public val incidentRoutingService: Output<String>? = null,
    public val incidentRoutingTeam: Output<String>? = null,
    public val manifestOwners: Output<List<String>>? = null,
    public val resourceAccessPolicy: Output<String>? = null,
    public val resourceAccessRoles: Output<List<Any>>? = null,
    public val schemaOwners: Output<List<String>>? = null,
    public val serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder()
            .incidentContactEmail(incidentContactEmail?.applyValue({ args0 -> args0 }))
            .incidentRoutingService(incidentRoutingService?.applyValue({ args0 -> args0 }))
            .incidentRoutingTeam(incidentRoutingTeam?.applyValue({ args0 -> args0 }))
            .manifestOwners(manifestOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceAccessPolicy(resourceAccessPolicy?.applyValue({ args0 -> args0 }))
            .resourceAccessRoles(resourceAccessRoles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .schemaOwners(schemaOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .serviceTreeInfos(
                serviceTreeInfos?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesManagementArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesManagementArgsBuilder internal constructor() {
    private var incidentContactEmail: Output<String>? = null

    private var incidentRoutingService: Output<String>? = null

    private var incidentRoutingTeam: Output<String>? = null

    private var manifestOwners: Output<List<String>>? = null

    private var resourceAccessPolicy: Output<String>? = null

    private var resourceAccessRoles: Output<List<Any>>? = null

    private var schemaOwners: Output<List<String>>? = null

    private var serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null

    /**
     * @param value
     */
    @JvmName("wnbefuadljyapxgk")
    public suspend fun incidentContactEmail(`value`: Output<String>) {
        this.incidentContactEmail = value
    }

    /**
     * @param value
     */
    @JvmName("cjxidbynbaudloef")
    public suspend fun incidentRoutingService(`value`: Output<String>) {
        this.incidentRoutingService = value
    }

    /**
     * @param value
     */
    @JvmName("lmhhbjgrjaqocjub")
    public suspend fun incidentRoutingTeam(`value`: Output<String>) {
        this.incidentRoutingTeam = value
    }

    /**
     * @param value
     */
    @JvmName("powrkwecddasmeqf")
    public suspend fun manifestOwners(`value`: Output<List<String>>) {
        this.manifestOwners = value
    }

    @JvmName("gygyethqdaeevmud")
    public suspend fun manifestOwners(vararg values: Output<String>) {
        this.manifestOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kdbkbnndaaksaljy")
    public suspend fun manifestOwners(values: List<Output<String>>) {
        this.manifestOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("uiwalvqsmsgmcole")
    public suspend fun resourceAccessPolicy(`value`: Output<String>) {
        this.resourceAccessPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("rpenoifxrdsclobt")
    public suspend fun resourceAccessRoles(`value`: Output<List<Any>>) {
        this.resourceAccessRoles = value
    }

    @JvmName("brbpivbbngvrkkks")
    public suspend fun resourceAccessRoles(vararg values: Output<Any>) {
        this.resourceAccessRoles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("wcdmbvomicgrrrjx")
    public suspend fun resourceAccessRoles(values: List<Output<Any>>) {
        this.resourceAccessRoles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("bqqqgoeeqixlhnqv")
    public suspend fun schemaOwners(`value`: Output<List<String>>) {
        this.schemaOwners = value
    }

    @JvmName("fgqybtlfajjutoju")
    public suspend fun schemaOwners(vararg values: Output<String>) {
        this.schemaOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("gbtojwtkwiynjesw")
    public suspend fun schemaOwners(values: List<Output<String>>) {
        this.schemaOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("gegykiqmovhiobwh")
    public suspend fun serviceTreeInfos(`value`: Output<List<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = value
    }

    @JvmName("wnvlwbreevqrwafp")
    public suspend fun serviceTreeInfos(vararg values: Output<ServiceTreeInfoArgs>) {
        this.serviceTreeInfos = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("bxmqowgbjtfubgmf")
    public suspend fun serviceTreeInfos(values: List<Output<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ekativmxvbinjcnh")
    public suspend fun incidentContactEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentContactEmail = mapped
    }

    /**
     * @param value
     */
    @JvmName("jjdyxtevaaoglqrj")
    public suspend fun incidentRoutingService(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingService = mapped
    }

    /**
     * @param value
     */
    @JvmName("tqpiyhtxxqxijdgj")
    public suspend fun incidentRoutingTeam(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingTeam = mapped
    }

    /**
     * @param value
     */
    @JvmName("vsksaedqlhtjeblm")
    public suspend fun manifestOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("xbbtxliesfrmdrbp")
    public suspend fun manifestOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("jxyrwspbwltavwhd")
    public suspend fun resourceAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("rcgqyyheqcphnmpn")
    public suspend fun resourceAccessRoles(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param values
     */
    @JvmName("ehdfxcwquhfhgfoy")
    public suspend fun resourceAccessRoles(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param value
     */
    @JvmName("usfnvkvtvvlhtnmk")
    public suspend fun schemaOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("ohspjkmcrrwwwvif")
    public suspend fun schemaOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("monnblhhooxhbpnk")
    public suspend fun serviceTreeInfos(`value`: List<ServiceTreeInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pqhffbhdbyrrrqwo")
    public suspend
    fun serviceTreeInfos(argument: List<suspend ServiceTreeInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("thonwkqhtgynelkw")
    public suspend fun serviceTreeInfos(
        vararg
        argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("cxttbwekbljiqobf")
    public suspend fun serviceTreeInfos(argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ServiceTreeInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param values
     */
    @JvmName("hfceffejglhxnfip")
    public suspend fun serviceTreeInfos(vararg values: ServiceTreeInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesManagementArgs =
        ResourceTypeRegistrationPropertiesManagementArgs(
            incidentContactEmail = incidentContactEmail,
            incidentRoutingService = incidentRoutingService,
            incidentRoutingTeam = incidentRoutingTeam,
            manifestOwners = manifestOwners,
            resourceAccessPolicy = resourceAccessPolicy,
            resourceAccessRoles = resourceAccessRoles,
            schemaOwners = schemaOwners,
            serviceTreeInfos = serviceTreeInfos,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property incidentContactEmail
 * @property incidentRoutingService
 * @property incidentRoutingTeam
 * @property manifestOwners
 * @property resourceAccessPolicy
 * @property resourceAccessRoles
 * @property schemaOwners
 * @property serviceTreeInfos
 */
public data class ResourceTypeRegistrationPropertiesManagementArgs(
    public val incidentContactEmail: Output<String>? = null,
    public val incidentRoutingService: Output<String>? = null,
    public val incidentRoutingTeam: Output<String>? = null,
    public val manifestOwners: Output<List<String>>? = null,
    public val resourceAccessPolicy: Output<String>? = null,
    public val resourceAccessRoles: Output<List<Any>>? = null,
    public val schemaOwners: Output<List<String>>? = null,
    public val serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder()
            .incidentContactEmail(incidentContactEmail?.applyValue({ args0 -> args0 }))
            .incidentRoutingService(incidentRoutingService?.applyValue({ args0 -> args0 }))
            .incidentRoutingTeam(incidentRoutingTeam?.applyValue({ args0 -> args0 }))
            .manifestOwners(manifestOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceAccessPolicy(resourceAccessPolicy?.applyValue({ args0 -> args0 }))
            .resourceAccessRoles(resourceAccessRoles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .schemaOwners(schemaOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .serviceTreeInfos(
                serviceTreeInfos?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesManagementArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesManagementArgsBuilder internal constructor() {
    private var incidentContactEmail: Output<String>? = null

    private var incidentRoutingService: Output<String>? = null

    private var incidentRoutingTeam: Output<String>? = null

    private var manifestOwners: Output<List<String>>? = null

    private var resourceAccessPolicy: Output<String>? = null

    private var resourceAccessRoles: Output<List<Any>>? = null

    private var schemaOwners: Output<List<String>>? = null

    private var serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null

    /**
     * @param value
     */
    @JvmName("uuglcxtsxfpdjnic")
    public suspend fun incidentContactEmail(`value`: Output<String>) {
        this.incidentContactEmail = value
    }

    /**
     * @param value
     */
    @JvmName("phuutfmjsgpmoalh")
    public suspend fun incidentRoutingService(`value`: Output<String>) {
        this.incidentRoutingService = value
    }

    /**
     * @param value
     */
    @JvmName("pblvxmlkvetbsnfb")
    public suspend fun incidentRoutingTeam(`value`: Output<String>) {
        this.incidentRoutingTeam = value
    }

    /**
     * @param value
     */
    @JvmName("qeserkxfrfigwbnm")
    public suspend fun manifestOwners(`value`: Output<List<String>>) {
        this.manifestOwners = value
    }

    @JvmName("trpdkdrppgdrvpll")
    public suspend fun manifestOwners(vararg values: Output<String>) {
        this.manifestOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("gyewsmouyleuudso")
    public suspend fun manifestOwners(values: List<Output<String>>) {
        this.manifestOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yarigvejndwrqyyq")
    public suspend fun resourceAccessPolicy(`value`: Output<String>) {
        this.resourceAccessPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("oacihkfmmujipusd")
    public suspend fun resourceAccessRoles(`value`: Output<List<Any>>) {
        this.resourceAccessRoles = value
    }

    @JvmName("acwihkoxtgkjyasm")
    public suspend fun resourceAccessRoles(vararg values: Output<Any>) {
        this.resourceAccessRoles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("upvdjvwwwawfomqv")
    public suspend fun resourceAccessRoles(values: List<Output<Any>>) {
        this.resourceAccessRoles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("phywhuersboumbbn")
    public suspend fun schemaOwners(`value`: Output<List<String>>) {
        this.schemaOwners = value
    }

    @JvmName("mcdxuhjjfrxyppfj")
    public suspend fun schemaOwners(vararg values: Output<String>) {
        this.schemaOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("afwcwvovshiboaks")
    public suspend fun schemaOwners(values: List<Output<String>>) {
        this.schemaOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("eqnafhfyfdvhpsgh")
    public suspend fun serviceTreeInfos(`value`: Output<List<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = value
    }

    @JvmName("pcgpbjyhbtggorjr")
    public suspend fun serviceTreeInfos(vararg values: Output<ServiceTreeInfoArgs>) {
        this.serviceTreeInfos = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("bfrsjbdbxwnjvrnr")
    public suspend fun serviceTreeInfos(values: List<Output<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("neuuurflwegxgbli")
    public suspend fun incidentContactEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentContactEmail = mapped
    }

    /**
     * @param value
     */
    @JvmName("oqflrhggknwhgnmg")
    public suspend fun incidentRoutingService(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingService = mapped
    }

    /**
     * @param value
     */
    @JvmName("feucxesqdbywtsns")
    public suspend fun incidentRoutingTeam(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingTeam = mapped
    }

    /**
     * @param value
     */
    @JvmName("btrhfxraggmugmbu")
    public suspend fun manifestOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("quncwaufdrjyxheg")
    public suspend fun manifestOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("ywdmplgosbrvndhs")
    public suspend fun resourceAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("wdfcwhtfknrrlhvm")
    public suspend fun resourceAccessRoles(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param values
     */
    @JvmName("xdvqehnoaarlosao")
    public suspend fun resourceAccessRoles(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param value
     */
    @JvmName("wyibpnmerxdveoap")
    public suspend fun schemaOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("fxwhcslcesxxwlia")
    public suspend fun schemaOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("wycxsyakdfnejide")
    public suspend fun serviceTreeInfos(`value`: List<ServiceTreeInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("emygknqxbeqnmbcs")
    public suspend
    fun serviceTreeInfos(argument: List<suspend ServiceTreeInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("occqksjagflpbpbk")
    public suspend fun serviceTreeInfos(
        vararg
        argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("mkgiymvyiudgtkeh")
    public suspend fun serviceTreeInfos(argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ServiceTreeInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param values
     */
    @JvmName("rhggquooyfhwqcmq")
    public suspend fun serviceTreeInfos(vararg values: ServiceTreeInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesManagementArgs =
        ResourceTypeRegistrationPropertiesManagementArgs(
            incidentContactEmail = incidentContactEmail,
            incidentRoutingService = incidentRoutingService,
            incidentRoutingTeam = incidentRoutingTeam,
            manifestOwners = manifestOwners,
            resourceAccessPolicy = resourceAccessPolicy,
            resourceAccessRoles = resourceAccessRoles,
            schemaOwners = schemaOwners,
            serviceTreeInfos = serviceTreeInfos,
        )
}
